@@ -23,6 +23,7 @@ import org.bouncycastle.bcpg.sig.KeyFlags;
 import org.bouncycastle.bcpg.sig.NotationData;
 import org.bouncycastle.bcpg.sig.PreferredAlgorithms;
 import org.bouncycastle.bcpg.sig.PrimaryUserID;
+import org.bouncycastle.bcpg.sig.RegularExpression;
 import org.bouncycastle.bcpg.sig.Revocable;
 import org.bouncycastle.bcpg.sig.RevocationKey;
 import org.bouncycastle.bcpg.sig.RevocationReason;
@@ -141,6 +142,9 @@ public final class SignatureSubpacketsUtil {
      * @return signature creation time subpacket
      */
     public static @Nullable SignatureCreationTime getSignatureCreationTime(PGPSignature signature) {
+        if (signature.getVersion() == 3) {
+            return new SignatureCreationTime(false, signature.getCreationTime());
+        }
         return hashed(signature, SignatureSubpacket.signatureCreationTime);
     }
 
@@ -527,6 +531,11 @@ public final class SignatureSubpacketsUtil {
         return hashed(signature, SignatureSubpacket.exportableCertification);
     }
 
+    public static boolean isExportable(PGPSignature signature) {
+        Exportable exportable = getExportableCertification(signature);
+        return exportable == null || exportable.isExportable();
+    }
+
     /**
      * Return the trust signature packet from the signatures hashed area.
      *
@@ -537,6 +546,39 @@ public final class SignatureSubpacketsUtil {
         return hashed(signature, SignatureSubpacket.trustSignature);
     }
 
+    public static int getTrustDepthOr(PGPSignature signature, int defaultDepth) {
+        TrustSignature packet = getTrustSignature(signature);
+        if (packet != null) {
+            return packet.getDepth();
+        }
+        return defaultDepth;
+    }
+
+    public static int getTrustAmountOr(PGPSignature signature, int defaultAmount) {
+        TrustSignature packet = getTrustSignature(signature);
+        if (packet != null) {
+            return packet.getTrustAmount();
+        }
+        return defaultAmount;
+    }
+
+    /**
+     * Return all regular expression subpackets from the hashed area of the given signature.
+     *
+     * @param signature signature
+     * @return list of regular expressions
+     */
+    public static List<RegularExpression> getRegularExpressions(PGPSignature signature) {
+        org.bouncycastle.bcpg.SignatureSubpacket[] subpackets = signature.getHashedSubPackets()
+                .getSubpackets(SignatureSubpacket.regularExpression.getCode());
+        List<RegularExpression> regularExpressions = new ArrayList<>(subpackets.length);
+        for (org.bouncycastle.bcpg.SignatureSubpacket subpacket : subpackets) {
+            regularExpressions.add((RegularExpression) subpacket);
+        }
+        return regularExpressions;
+    }
+
+
     /**
      * Select a list of all signature subpackets of the given type, which are present in the hashed area of
      * the given signature.
