@@ -9,13 +9,27 @@ import java.io.InputStream;
 
 import org.bouncycastle.bcpg.ArmoredInputStream;
 
+import javax.annotation.Nonnull;
+
+/**
+ * Factory class for instantiating preconfigured {@link ArmoredInputStream ArmoredInputStreams}.
+ * {@link #get(InputStream)} will return an {@link ArmoredInputStream} that is set up to properly detect CRC errors.
+ */
 public final class ArmoredInputStreamFactory {
 
     private ArmoredInputStreamFactory() {
 
     }
 
-    public static ArmoredInputStream get(InputStream inputStream) throws IOException {
+    /**
+     * Return an instance of {@link ArmoredInputStream} which will detect CRC errors.
+     *
+     * @param inputStream input stream
+     * @return armored input stream
+     * @throws IOException in case of an IO error
+     */
+    @Nonnull
+    public static ArmoredInputStream get(@Nonnull InputStream inputStream) throws IOException {
         if (inputStream instanceof CRCingArmoredInputStreamWrapper) {
             return (ArmoredInputStream) inputStream;
         }
