@@ -7,6 +7,7 @@ package org.pgpainless.sop;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.IOException;
@@ -21,6 +22,7 @@ import org.pgpainless.key.info.KeyRingInfo;
 import org.pgpainless.key.protection.UnlockSecretKey;
 import org.pgpainless.util.Passphrase;
 import sop.SOP;
+import sop.exception.SOPGPException;
 
 public class GenerateKeyTest {
 
@@ -92,4 +94,16 @@ public class GenerateKeyTest {
             assertNotNull(UnlockSecretKey.unlockSecretKey(key, Passphrase.fromPassword("sw0rdf1sh")));
         }
     }
+
+    @Test
+    public void invalidProfile() {
+        assertThrows(SOPGPException.UnsupportedProfile.class, () ->
+                sop.generateKey().profile("invalid"));
+    }
+
+    @Test
+    public void nullProfile() {
+        assertThrows(SOPGPException.UnsupportedProfile.class, () ->
+                sop.generateKey().profile((String) null));
+    }
 }
